@@ -203,7 +203,7 @@ def _load_optix_win():
     optix.update_graph.argtypes = [c_wchar_p, c_wchar_p, c_int, c_int, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p]
     optix.update_graph.restype = c_uint
 
-    optix.setup_mesh.argtypes = [c_wchar_p, c_wchar_p, c_int, c_int, c_int, c_int, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_bool]
+    optix.setup_mesh.argtypes = [c_wchar_p, c_wchar_p, c_int, c_int, c_int, c_int, c_int, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_bool]
     optix.setup_mesh.restype = c_uint
 
     optix.update_mesh.argtypes = [c_wchar_p, c_wchar_p, c_int, c_int, c_int, c_int, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p, c_void_p]
@@ -275,6 +275,9 @@ def _load_optix_win():
     optix.update_geom_buffers.argtypes = [c_wchar_p, c_uint, c_bool]
     optix.update_geom_buffers.restype = c_bool
 
+    optix.delete_geometry.argtypes = [c_wchar_p]
+    optix.delete_geometry.restype = c_bool
+
     optix.set_coordinates_geom.argtypes = [c_int, c_float]
     optix.set_coordinates_geom.restype = c_bool
 
@@ -692,7 +695,7 @@ class _ClrOptiX:
                                             IntPtr.__overloads__[Int64](cast(normal_ptr_ref, c_void_p).value),
                                             IntPtr.__overloads__[Int64](cast(normal_size_ref, c_void_p).value))
 
-    def get_device_buffers(self, width, height,
+    def get_device_buffers(self,
                      img_ptr_ref, img_size_ref,
                      raw_ptr_ref, raw_size_ref,
                      hit_ptr_ref, hit_size_ref,
@@ -825,8 +828,8 @@ class _ClrOptiX:
                                            IntPtr.__overloads__[Int64](cconst),
                                            IntPtr.__overloads__[Int64](c))
 
-    def setup_mesh(self, name, material, n_vtx, n_tri, n_norm, n_uv, pos, cconst, c, vidx, norm, nidx, uvmap, uvidx, make_normals):
-        return self._optix.setup_mesh_ptr(name, material, n_vtx, n_tri, n_norm, n_uv,
+    def setup_mesh(self, name, material, n_vtx, n_tri, n_col, n_norm, n_uv, pos, cconst, c, vidx, norm, nidx, uvmap, uvidx, make_normals):
+        return self._optix.setup_mesh_ptr(name, material, n_vtx, n_tri, n_col, n_norm, n_uv,
                                           IntPtr.__overloads__[Int64](pos),
                                           IntPtr.__overloads__[Int64](cconst),
                                           IntPtr.__overloads__[Int64](c),
@@ -901,6 +904,8 @@ class _ClrOptiX:
 
     def update_geom_buffers(self, name, mask, forced): return self._optix.update_geom_buffers(name, mask, forced)
 
+    def delete_geometry(self, name): return self._optix.delete_geometry(name)
+
     def set_coordinates_geom(self, mode, thickness): return self._optix.set_coordinates_geom(mode, thickness)
 
     def setup_camera(self, name, camera_type, eye, target, up, aperture_r, aperture_fract, focal_scale, chroma_l, chroma_t, fov, blur, glock, textures, make_current):
